> __vkquick__ — Это асинхронный фреймворк для разработки _легкоподдерживаемых_ чат-ботов ВКонтакте на Python

## Почему vkquick?
Основная задача vkquick — обеспечить разработчика бота максимально _автоматизированным_ функционалом настолько, насколько это возможно, при этом оставляя возможность полного управления. Терминальный инструмент, позволяющий создавать команду буквально в одну строку и автоматически перезугружающий бота при изменениях в коде для комфортной разработки наряду с красочным режимом дебага, асинхронный код, выглядящий как синхронный и минималистичный синтаксис распарсинга команд вместо 1000 if, а также вагон полезных инструментов для _частовстречающихся_ кейсов позволяют практически не задумываться над _излишней_ работой с API и прочей рутинной работой, а сконцентрировать внимание именно на построении логики обработки.

Для обычного бота, отвечающего на ваше сообщение, Вам нужно написать ровно 0 строк кода на Python. Не верите? Убедитесь в этом сами [на сайте нашей документации](https://rhinik.github.io/installation/)!
